import { LineLineIntersector } from "./collision/line_line_intersector";
import { AggregationTree } from "./collision/tree/aggregation_tree";
import { LinePointIntersector } from "./collision/line_point_intersector";
import { LineCurveIntersector } from "./collision/line_curve_intersector";
import { CurveCurveIntersector } from "./collision/curve_curve_intersector";
import { CurvePointIntersector } from "./collision/curve_point_intersector";
import { PointPointIntersector } from "./collision/point_point_intersector";
var CollisionAggregator = /** @class */ (function () {
    function CollisionAggregator() {
        this._intersectorRegistry = [new LineLineIntersector(), new LinePointIntersector(),
            new LineCurveIntersector(), new CurveCurveIntersector(), new CurvePointIntersector(), new PointPointIntersector()];
    }
    // aggregate commands together if they intersect
    CollisionAggregator.prototype.aggregate = function (pathCommands) {
        var _this = this;
        var flatCommands = pathCommands
            .flatMap(function (commands) { return commands; });
        var aggregationTree = new AggregationTree(function (shape1, shape2) { return _this.intersect(shape1, shape2, _this._intersectorRegistry); });
        flatCommands.forEach(function (command) {
            aggregationTree.addValue(command);
        });
        return aggregationTree.getAggregatedCommands();
    };
    // find intersector for two commands and call it
    CollisionAggregator.prototype.intersect = function (cmd1, cmd2, registry) {
        var matchingIntersector = registry.find(function (intersector) {
            var cmdType = intersector.supportedCommandTypes();
            return (cmdType[0].includes(cmd1.code) && cmdType[1].includes(cmd2.code)) ||
                (cmdType[1].includes(cmd1.code) && cmdType[0].includes(cmd2.code));
        });
        if (matchingIntersector === undefined) {
            throw new Error("intersector not defined for types ".concat(cmd1.code, " ").concat(cmd2.code));
        }
        if (matchingIntersector.supportedCommandTypes()[0].includes(cmd1.code)) {
            return matchingIntersector.intersects(cmd1, cmd2);
        }
        else {
            return matchingIntersector.intersects(cmd2, cmd1);
        }
    };
    return CollisionAggregator;
}());
export { CollisionAggregator };
//# sourceMappingURL=collision_aggregator.js.map