import { Vector } from "matter-js";
import { findAngle, findCenterOfLine, findDistanceVec } from "./math_utils";
import { Bezier } from "./../bezierjs/bezier.js";
export var findCenterOfCommand = function (command) {
    switch (command.code) {
        case "M": return Vector.create(command.x, command.y);
        case "T": throw new Error("T not supported");
        case "Z": return findCenterOfLineCommand(command);
        case "C": return findCenterOfCurveCommand(command);
        case "Q": return findCenterOfCurveCommand(command);
        case "S": return findCenterOfCurveCommand(command);
        case "L": return findCenterOfLineCommand(command);
    }
};
export var findCenterOfCurveCommand = function (command) {
    var points = findCurvePoints(command);
    var bezierCenter = new Bezier(points).get(0.5);
    return Vector.create(bezierCenter.x, bezierCenter.y);
};
export var findCenterOfLineCommand = function (command) {
    return findCenterOfLine(Vector.create(command.x, command.y), Vector.create(command.x0, command.y0));
};
export var findAngleOfLineCommand = function (command) {
    return findAngle(command.x, command.y, command.x0, command.y0);
};
export var findLengthOfLineCommand = function (command) {
    return findDistanceVec(Vector.create(command.x, command.y), Vector.create(command.x0, command.y0));
};
export var findCurvePoints = function (command) {
    switch (command.code) {
        case 'C':
            {
                return [
                    Vector.create(command.x0, command.y0),
                    Vector.create(command.x1, command.y1),
                    Vector.create(command.x2, command.y2),
                    Vector.create(command.x, command.y),
                ];
            }
        case 'Q':
            {
                return [
                    Vector.create(command.x0, command.y0),
                    Vector.create(command.x1, command.y1),
                    Vector.create(command.x, command.y),
                ];
            }
        case "S":
            {
                return [
                    Vector.create(command.x0, command.y0),
                    Vector.create(command.x2, command.y2),
                    Vector.create(command.x, command.y),
                ];
            }
        case "T":
            {
                throw new Error("T not defined");
            }
    }
};
//# sourceMappingURL=command_utils.js.map