import { Bezier } from "../../bezierjs/bezier.js";
import { Bodies, Vector } from "matter-js";
import { findDistanceVec, findAngle } from "../../base/math_utils";
import { findCurvePoints } from "../../base/command_utils";
var AbstractCurveBody = /** @class */ (function () {
    function AbstractCurveBody() {
    }
    AbstractCurveBody.prototype.createPoints = function (bezier, numberOfPoints) {
        var fraction = 1 / numberOfPoints;
        return Array.from(Array(numberOfPoints + 1).keys()).map(function (i) { return bezier.get(i * fraction); });
    };
    AbstractCurveBody.prototype.createInnerBodies = function (colliderSize, curve) {
        var curvePoints = findCurvePoints(curve);
        var bezierPoints = this.createPoints(new Bezier(curvePoints), 3);
        return bezierPoints
            .filter(function (bp, index) { return index < bezierPoints.length - 1; })
            .map(function (bp, index) {
            var current = Vector.create(bp.x, bp.y);
            var next = Vector.create(bezierPoints[index + 1].x, bezierPoints[index + 1].y);
            var direction = Vector.normalise(Vector.sub(next, current));
            var midPoint = Vector.create((current.x + next.x) / 2, (current.y + next.y) / 2);
            var d = findDistanceVec(next, current);
            return Bodies.rectangle(midPoint.x, midPoint.y, d, colliderSize, {
                angle: findAngle(next.x, next.y, current.x, current.y)
            });
        });
    };
    return AbstractCurveBody;
}());
export { AbstractCurveBody };
//# sourceMappingURL=abstract_curve_body.js.map