import * as Matter from "matter-js";
import { Body, World } from "matter-js";
import { findCenterOfCommand } from "../base/command_utils";
import { physBodyFactory } from "./body/body_factory";
var Engine = Matter.Engine;
var Runner = Matter.Runner;
var Bodies = Matter.Bodies;
var MatterJsPhysics = /** @class */ (function () {
    function MatterJsPhysics(svgData, globalConfig, plugins) {
        var _this = this;
        this._svgData = svgData;
        this._engine = Engine.create();
        this._world = this._engine.world;
        this._commandBodies = [];
        this._plugins = plugins;
        var rootBodies = [];
        svgData.aggregatedCommands.forEach(function (commands) {
            var midX = commands
                .map(function (command) { return findCenterOfCommand(command).x; })
                .reduce(function (acc, cur) { return acc + cur; }) / commands.length;
            var midY = commands
                .map(function (command) { return findCenterOfCommand(command).y; })
                .reduce(function (acc, cur) { return acc + cur; }) / commands.length;
            var rootBody = Bodies.circle(midX, midY, 3000, globalConfig);
            var commandBodies = commands.map(function (command) { return physBodyFactory(command, globalConfig.colliderWidth); });
            _this._commandBodies = _this._commandBodies.concat(commandBodies);
            var physBodies = commandBodies.map(function (physBody) { return physBody.bodies; }).flatMap(function (body) { return body; });
            Body.setParts(rootBody, physBodies, false);
            World.add(_this._world, rootBody);
            rootBodies.push(rootBody);
        });
        plugins.forEach(function (plugin) { return plugin.setup(svgData, _this._engine, rootBodies); });
    }
    MatterJsPhysics.prototype.update = function (aggregatedShapes) {
        // update physics
        Engine.update(this._engine);
        this._commandBodies.forEach(function (body) { return body.updateSvgCommand(); });
    };
    MatterJsPhysics.prototype.stop = function () {
        this._plugins.forEach(function (plugin) { return plugin.stop(); });
    };
    return MatterJsPhysics;
}());
export { MatterJsPhysics };
//# sourceMappingURL=matterjs_physics.js.map