import { Body, Composite, Events, Query, Vector } from "matter-js";
var MousePlugin = /** @class */ (function () {
    function MousePlugin(mouseForce) {
        this._mouseForce = mouseForce;
    }
    MousePlugin.prototype.setup = function (svgData, engine, rootBodies) {
        var _this = this;
        var world = engine.world;
        svgData.svg.addEventListener("mousemove", function (ev) {
            _this._mousePos = Vector.create(ev.offsetX, ev.offsetY);
        });
        Events.on(engine, 'afterUpdate', function () {
            if (_this._previousMousePos !== undefined && _this._mousePos !== undefined) {
                var bodies = Query.point(Composite.allBodies(world), _this._mousePos);
                bodies.forEach(function (body) {
                    var direction = Vector.normalise(Vector.sub(_this._mousePos, _this._previousMousePos));
                    Body.applyForce(body, _this._mousePos, Vector.mult(direction, _this._mouseForce));
                });
            }
            _this._previousMousePos = _this._mousePos;
        });
    };
    MousePlugin.prototype.stop = function () {
        // TODO: remove mouse listener
    };
    return MousePlugin;
}());
export { MousePlugin };
//# sourceMappingURL=mouse_plugin.js.map