import { Body, Composite, Events, Vector } from "matter-js";
var ScrollPlugin = /** @class */ (function () {
    function ScrollPlugin(force) {
        this._force = force;
    }
    ScrollPlugin.prototype.setup = function (svgData, physEngine, rootBodies) {
        var _this = this;
        var world = physEngine.world;
        this._listener = function (ev) { return _this._scrollPos = Vector.create(window.scrollX, window.scrollY); };
        window.addEventListener("scroll", this._listener);
        Events.on(physEngine, 'afterUpdate', function () {
            if (_this._scrollPos !== undefined && _this._previousScrollPos !== undefined) {
                var bodies = Composite.allBodies(world);
                bodies.forEach(function (body) {
                    var direction = Vector.normalise(Vector.sub(_this._scrollPos, _this._previousScrollPos));
                    Body.applyForce(body, body.position, Vector.mult(direction, _this._force));
                });
            }
            _this._previousScrollPos = _this._scrollPos;
        });
    };
    ScrollPlugin.prototype.stop = function () {
        window.removeEventListener("scroll", this._listener);
    };
    return ScrollPlugin;
}());
export { ScrollPlugin };
//# sourceMappingURL=scroll_plugin.js.map